@@ -4,7 +4,7 @@
 ## Author:      Mattia Barbon
 ## Modified by:
 ## Created:     01/10/2000
-## RCS-ID:      $Id: Wx.pm 2329 2008-01-20 09:52:38Z mbarbon $
+## RCS-ID:      $Id: Wx.pm 2390 2008-05-14 20:36:51Z mbarbon $
 ## Copyright:   (c) 2000-2008 Mattia Barbon
 ## Licence:     This program is free software; you can redistribute it and/or
 ##              modify it under the same terms as Perl itself
@@ -21,7 +21,7 @@ use vars qw(@ISA $VERSION $XS_VERSION $AUTOLOAD @EXPORT_OK %EXPORT_TAGS
 $_msw = 1; $_gtk = 2; $_motif = 3; $_mac = 4; $_x11 = 5;
 
 @ISA = qw(Exporter);
-$VERSION = '0.82';
+$VERSION = '0.83';
 $XS_VERSION = $VERSION;
 $VERSION = eval $VERSION;
 
@@ -77,7 +77,7 @@ sub import {
 }
 
 sub END {
-  UnLoad();
+  UnLoad() if defined &UnLoad;
 }
 
 sub _match(\@$;$$) { &_xsmatch( [@{shift()}],@_ ) }
@@ -167,7 +167,7 @@ if( Load() ) {
 }
 
 sub END {
-  UnsetConstants();
+  UnsetConstants() if defined &UnsetConstants;
 }
 
 #
